@@ -23,11 +23,11 @@ Artifactory::Client - Perl client for Artifactory REST API
 
 =head1 VERSION
 
-Version 0.9.3
+Version 1.0.0
 
 =cut
 
-our $VERSION = 'v0.9.3';
+our $VERSION = 'v1.0.0';
 
 =head1 SYNOPSIS
 
@@ -504,7 +504,7 @@ then recursively calculates the SHA256 of each item in the folder and attaches t
 sub set_item_sha256_checksum {
     my ( $self, %args ) = @_;
     my $url = $self->_api_url() . '/checksum/sha256';
-    return $self->put(
+    return $self->post(
         $url,
         "Content-Type" => 'application/json',
         Content        => $self->_json->encode( \%args )
@@ -571,6 +571,20 @@ sub retrieve_build_artifacts_archive {
     );
 }
 
+=head2 retrieve_folder_or_repository_archive( path => '/foobar', archiveType => 'zip' )
+
+Retrieves an archive file (supports zip/tar/tar.gz/tgz) containing all the artifacts that reside under the specified
+path (folder or repository root). Requires Enable Folder Download to be set.
+
+=cut
+
+sub retrieve_folder_or_repository_archive {
+    my ( $self, %args ) = @_;
+    my $path = delete $args{path};
+    my $url = $self->_api_url() . '/archive/download' . $path . '?' . $self->_stringify_hash( '', %args );
+    return $self->get($url);
+}
+
 =head2 trace_artifact_retrieval( $path )
 
 Takes path and traces artifact retrieval
@@ -874,6 +888,24 @@ sub delete_local_multi_push_replication {
     return $self->delete($call_url);
 }
 
+=head2 artifact_sync_download( $path, content => 'progress', mark => 1000 )
+
+Downloads an artifact with or without returning the actual content to the client. When tracking the progress marks are
+printed (by default every 1024 bytes). This is extremely useful if you want to trigger downloads on a remote Artifactory
+server, for example to force eager cache population of large artifacts, but want to avoid the bandwidth consumption
+involved in transferring the artifacts to the triggering client. If no content parameter is specified the file content
+is downloaded to the client.
+
+=cut
+
+sub artifact_sync_download {
+    my ( $self, $path, %args ) = @_;
+    my $repo = $self->repository();
+    my $url  = $self->_api_url() . "/download/$repo" . $path;
+    $url .= "?" . $self->_stringify_hash( '&', %args ) if (%args);
+    return $self->get($url);
+}
+
 =head2 file_list( $dir, %opts )
 
 Get a flat (the default) or deep listing of the files and folders (not included by default) within a folder
@@ -1487,19 +1519,6 @@ sub calculate_npm_repository_metadata {
     return $self->_handle_repository_reindex("/npm/$repository/reindex");
 }
 
-=head2 calculate_bower_repository_metadata
-
-Recalculates the bower search index for this repository (local/virtual). Please see the Bower integration documentation for
-more details.
-
-=cut
-
-sub calculate_bower_repository_metadata {
-    my $self       = shift;
-    my $repository = $self->repository();
-    return $self->_handle_repository_reindex("/bower/$repository/reindex");
-}
-
 =head2 calculate_maven_index( repos => [ 'repo1', 'repo2' ], force => 0/1 )
 
 Calculates/caches a Maven index for the specified repositories
